@@ -3,13 +3,7 @@ hover_reply <- function(id, uri, workspace, document, position) {
     character <- position$character
 
     if (!check_scope(uri, document, line)) {
-        Response$new(
-            id,
-            result = list(
-                contents = NULL
-            )
-        )
-        return(invisible(NULL))
+        return(Response$new(id))
     }
 
     hover <- detect_hover(document, line, character)
@@ -20,10 +14,12 @@ hover_reply <- function(id, uri, workspace, document, position) {
         hover, "(?:([a-zA-Z][a-zA-Z0-9]+)(:::?))?([a-zA-Z0-9_.]*)$")
 
     contents <- tryCatch(
-        get_help(matches[4], matches[2]),
-        error = function(e) NULL)
+        workspace$get_help(matches[4], matches[2]),
+        error = function(e) list())
 
-    if (!is.null(contents)) {
+    if (is.null(contents)) {
+        Response$new(id)
+    } else {
         Response$new(
             id,
             result = list(
